<?php

/**
 * Waitingroom.class.php
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * @author Heiko Dostert <dosterth@uni-trier.de>
 * @package portaLE
 * @copyright Universitt Trier, Koordinationsstelle E-Learning, 2010
 * @version 1.0.0
 */


require_once dirname(__FILE__) . '/WaitingPerson.class.php';

class Waitingroom
{
	static function enterRoom($id, $user)
	{
		if(!is_int($id))
			return false;
		$db = DBManager::Get();
		$q = sprintf('REPLACE INTO portaLE_waitingroom SET conference_id = %d, firstname = %s, lastname = %s, user_id = %s', $id, $db->quote($user->getGivenname()), $db->quote($user->getSurname()), $db->quote($user->getUserid())); 
		$db->exec($q);
		$q = "UPDATE portaLE_conferences SET timestamp = NOW() WHERE id = $id";
		DBManager::Get()->exec($q);
	}


  	static function leaveRoom($id, $user_id)
	{
		if(!is_int($id))
			return false;
		$db = DBManager::Get();
		$q = sprintf("DELETE FROM portaLE_waitingroom WHERE conference_id = %d AND user_id = %s", $id, $db->quote($user_id));
		$db->exec($q);
		$q = "UPDATE portaLE_conferences SET timestamp = NOW() WHERE id = $id";
		$db->exec($q);
	}

	
  	static function getWaitinglist($id)
	{
		$db = DBManager::get();
		$preparation = $db->prepare("SELECT * FROM portaLE_waitingroom WHERE conference_id = :id ORDER BY activated desc, timestamp asc", array(PDO::ATTR_CURSOR => PDO::CURSOR_FWDONLY));
		$preparation->execute(array('id' => $id));
		$results = $preparation->fetchAll(PDO::FETCH_ASSOC);
		$waitingList = array();
		foreach ($results as $result)
		{
			$timestamp = strtotime($result['timestamp']);
			array_push($waitingList, new WaitingPerson($result['user_id'], $timestamp, $result['firstname'], $result['lastname'], $result['activated']));
		}
		return $waitingList;
	}
	
	
	//get the time of the last change in the waiting room:
	static function getTimeOfWaitinglist($id){
		$db = DBManager::get();
		$preparation = $db->prepare("SELECT timestamp FROM portaLE_conferences WHERE id = :id", array(PDO::ATTR_CURSOR => PDO::CURSOR_FWDONLY));
		$preparation->execute(array('id' => $id));
		$data = $preparation->fetch();
		if($data === false)
			return false;
		return $data['timestamp'];
	}
	
	static function allowEntry($id, $user_id){
		if(!is_int($id))
			return false;
		$time = time();
		$db = DBManager::get();
		$q = sprintf("UPDATE portaLE_waitingroom SET activated = %d WHERE conference_id = %d AND user_id = %s", $time, $id, $db->quote($user_id));
		$db->exec($q);
		$q = "UPDATE portaLE_conferences SET timestamp = NOW() WHERE id = $id";
		$db->exec($q);
	}
	
	//test if a student has the permission to enter the virtual room: 
	static function hasEntryPermission($id, $user_id){
		$db = DBManager::get();
		$preparation = $db->prepare("SELECT activated FROM portaLE_waitingroom WHERE conference_id = :id AND user_id = :user_id", array(PDO::ATTR_CURSOR => PDO::CURSOR_FWDONLY));
		$preparation->execute(array('id' => $id, 'user_id' => $user_id));
		$data = $preparation->fetch();
		if($data === false)
			return false;
		if($data['activated']>0)
			return true;
		return
			false;		 
	}

	//publish a message in the waiting room:
	static function sendMessage($id, $message){
		if(!is_int($id))
			return false;
		$db = DBManager::get();
		$q = sprintf("UPDATE portaLE_conferences SET waitingroomMessage = %s, timestamp = NOW() WHERE id = %d AND seminar_id = %s", $db->quote($message), $id, $db->quote($_SESSION['SessSemName'][1]));
		$db->exec($q);
	}
	
	
	//close or re-open a waiting room:
	static function close($id, $status=true){
		if(!is_int($id))
			return false;
		$db = DBMAnager::get();
		if($status)
			$q = sprintf("UPDATE portaLE_conferences SET waitingroomClosed = 1 WHERE id = %d AND seminar_id = %s", $id, $db->quote($_SESSION['SessSemName'][1]));
		else
			$q = sprintf("UPDATE portaLE_conferences SET waitingroomClosed = 0 WHERE id = %d AND seminar_id = %s", $id, $db->quote($_SESSION['SessSemName'][1]));
		$db->exec($q);
	}
	
	
	//test if a waiting room has been closed by the teacher: 
	static function getStatus($id){
		$db = DBManager::get();
		$preparation = $db->prepare("SELECT waitingroomClosed FROM portaLE_conferences WHERE id = :id", array(PDO::ATTR_CURSOR => PDO::CURSOR_FWDONLY));
		$preparation->execute(array('id' => $id));
		$data = $preparation->fetch();
		if($data === false)
			return false;
		return ($data['waitingroomClosed']==1);
	}
		
	
	//get relevant information about a conference room to be published in the waiting room:
	static function getClassroomInfo($id){
		$db = DBManager::get();
		$preparation = $db->prepare("SELECT title, date, length, waitingroomMessage AS message, auth_user_md5.Vorname AS firstname, auth_user_md5.Nachname AS lastname FROM portaLE_conferences, auth_user_md5 WHERE portaLE_conferences.teacher = auth_user_md5.user_id AND portaLE_conferences.id = :id", array(PDO::ATTR_CURSOR => PDO::CURSOR_FWDONLY));
		$preparation->execute(array('id' => $id));
		$data = $preparation->fetch();
		if($data === false)
			return false;
		return $data;		
	}
	
}
?>